Django Grappelli
================

**A jazzy skin for the Django admin interface**.

Grappelli is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

Code
----

https://github.com/sehmaschine/django-grappelli

Website
-------

http://www.grappelliproject.com

Documentation
-------------

http://readthedocs.org/docs/django-grappelli/

Releases
--------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.**

* Grappelli 2.7.3 (January 11th, 2016): Compatible with Django 1.8
* Grappelli 2.6.5 (May 28th, 2015): Compatible with Django 1.7
* Grappelli 2.5.7 (March 27th, 2015): Compatible with Django 1.6

Current development branches:

* Grappelli 2.7.4 (Development version for Django 1.8, see branch Stable/2.7.x)
* Grappelli 2.6.6 (Development version for Django 1.7, see branch Stable/2.6.x)
* Grappelli 2.5.8 (Development version for Django 1.6, see branch Stable/2.5.x)

Older versions are available at GitHub, but are not supported anymore.
Support for 2.5.x and 2.6.x is limited to security issues and very important bugfixes.
